package com.kjj.qa.cases;

import com.google.inject.internal.asm.$TypePath;
import com.kjj.qa.utils.NetworkUtil;
import io.restassured.response.Response;
import org.testng.Assert;
import org.testng.annotations.AfterClass;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.IExpectedExceptionsAnnotation;
import org.testng.annotations.Test;
import org.testng.remote.strprotocol.IMessage;

import java.io.IOException;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static com.kjj.qa.config.BasicConfig.*;
import static com.kjj.qa.config.BasicConfig.BOSS_USERINFO;

public class Boss {
    private static final NetworkUtil network = NetworkUtil.getInstance();
    String sellerId = "";
    String usellerId ="";
    String sids ="";

    @BeforeClass
    public void setUp() {

    }
    //BOSS看板正式版
    //判断代理人的会员及版本
    @Test(description="会员及版本判断",priority = 1)
    public void 会员及版本判断() throws IOException{
        Response response = network.getResponse(BOSS_VERSIONINFO);
        int userVersion = response.jsonPath().getInt("data.find {it.openType == 1}.userVersion");//判断是否为保险版：1是通用版 2是保险版
        boolean isVip = response.jsonPath().getBoolean("data.find {it.openType == 1}.vip");//判断是否为会员
        Assert.assertEquals(userVersion, 2,network.message(BOSS_VERSIONINFO,"获取版本有误 此版本为非保险版"));
        Assert.assertTrue(isVip,network.message(BOSS_VERSIONINFO,"会员判断错误 为非会员"));
    }

    //获取info接口的代理人id
    @Test(description="获取代理人id",priority = 2)
    public void 获取代理人id() throws IOException{
        Response response = network.getResponse(BOSS_USERINFO);
        sellerId = response.jsonPath().getString("data.sellerId");
        Assert.assertNotNull(sellerId,network.message(BOSS_USERINFO,"获取sellerid失败"));
    }

    //代理人有无上下级判断；
    @Test(description="当前代理人角色判断",priority = 3)
    public void 当前代理人角色判断() throws IOException{
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("sellerId",sellerId);
        Response response = network.getResponse(params,BOSS_ROLE);
        boolean hasSubordinate = response.jsonPath().getBoolean("data.hasSubordinate");//判断是否有下级
        boolean hasSuperior = response.jsonPath().getBoolean("data.hasSuperior");//判断是否有上级
        Assert.assertFalse(hasSubordinate, network.message(params,BOSS_ROLE,"暂无下级"));
        Assert.assertTrue(hasSuperior,network.message(params,BOSS_ROLE,"暂无上级"));

    }

    //分享链接邀请下级加入
    @Test(description="邀请成员加入",priority = 4)
    public void 邀请成员加入() throws IOException{
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("inviteType",2);
        Response response = network.getResponse(params,BOSS_CODE);
        boolean invite = response.jsonPath().getBoolean("success");
        Assert.assertTrue(invite,network.message(params,BOSS_CODE,"分享链接失败"));

    }

    //被邀请人点击链接接受邀请
    @Test(description="获取被邀请人身份",priority = 5)
    public void 获取被邀请人身份() throws IOException{
        //tku 切换为访客的
        network.agentCookies.put("tku",VISITOR_TKU);
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("sellerId",usellerId);
        Response response = network.getResponse(params,BOSS_IDENTITY);
        int identity = response.jsonPath().getInt("data.identity");  //1团长、2成员、3没有团队
        Assert.assertEquals(identity, 3, network.message(params,BOSS_IDENTITY,"被邀请人已有团队或已绑定上级,不能再接受邀请"));
    }


    //获取info接口的代理人id
    @Test(description="获取访客id",priority = 6)
    public void 获取访客id() throws IOException{
        Response response = network.getResponse(BOSS_USERINFO);
        usellerId = response.jsonPath().getString("data.sellerId");
        Assert.assertNotNull(usellerId,network.message(BOSS_USERINFO,"获取usellerid失败"));
    }


    //邀请结果判断
    @Test(description="邀请结果",priority = 7)
    public void 邀请结果() throws IOException{
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("inviterSid",sellerId);
        params.put("inviteType",2);
        Response response = network.getResponse(params,BOSS_BOUND);
        boolean data = response.jsonPath().getBoolean("data");  //1 true:邀请成功；2 false:邀请失败
        Assert.assertTrue(data, network.message(params,BOSS_BOUND,"接受邀请失败"));

    //获取被邀请人上级昵称
        Map<String, Object> inviteparams = new HashMap<String, Object>();
        params.put("sellerId",usellerId);
        Response responses = network.getResponse(inviteparams,BOSS_BOSS);
        String name = responses.jsonPath().getString("data");
        Assert.assertEquals(name,"$张",network.message(params,BOSS_BOSS,"昵称不匹配"));
    }


    //重新获取列表,代理人有无上下级判断；
    @Test(description="当前代理人角色二次判断",priority = 8)
    public void 当前代理人角色二次判断() throws IOException{
        //tku 切换为代理人的
        network.agentCookies.put("tku",AGENT_TKU);
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("sellerId",sellerId);
        Response response = network.getResponse(params,BOSS_ROLE);
        boolean hasSubordinate = response.jsonPath().getBoolean("data.hasSubordinate");//判断是否有下级
        boolean hasSuperior = response.jsonPath().getBoolean("data.hasSuperior");//判断是否有上级
        Assert.assertTrue(hasSubordinate, network.message(params,BOSS_ROLE,"暂无下级"));
        Assert.assertTrue(hasSuperior,network.message(params,BOSS_ROLE,"暂无上级"));

    }

    //团队长数据看板
    //代理人已存在下级直接进入团队长数据看板；获取上级团队昵称
    @Test(description="获取上级团队昵称",priority = 9)
    public void 获取上级团队昵称() throws IOException{
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("sellerId",sellerId);
        Response response = network.getResponse(params,BOSS_BOSS);
        String data = response.jsonPath().getString("data");
        Assert.assertEquals(data,"喜洋洋保险",network.message(params,BOSS_BOSS,"昵称不匹配"));
    }

    //获取代理人团队人数
    @Test(description="获取当前团队人数",priority = 10)
    public void 获取当前团队人数() throws IOException{
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("sellerId",sellerId);
        Response response = network.getResponse(params,BOSS_ROLE);
        boolean teamNumber = response.jsonPath().getBoolean("data.teamNumber");//获取团队人数包含自己
        Assert.assertNotNull(teamNumber,network.message(params,BOSS_ROLE,"获取团队人数失败"));

    }

    //获取团队成员sids
    @Test(description="获取成员sids",priority = 11)
    public void 获取成员sids() throws IOException{
        Response response = network.getResponse(BOSS_MEMBER);
        sids = response.jsonPath().getString("data.list[0].sellerId");
        Assert.assertNotNull(sids,network.message(BOSS_MEMBER,"获取sids失败"));
    }

    //移除团队成员
    @Test(description="移除团队成员",priority = 12)
    public void 移除团队成员() throws IOException{
        Map<String, Object> params = new HashMap<String, Object>();
        List<String> ss= Collections.singletonList(sids);
        params.put("sids",ss);
        Response response = network.postResponse(params,BOSS_REMOVE);
        System.out.println(response.getBody().prettyPrint());
        boolean data = response.jsonPath().getBoolean("data");  //true:删除成功；false:删除失败
        Assert.assertEquals(data,true,network.message(params,BOSS_REMOVE, "移除失败"));

    }

    //代理人无下级直接进入个人数据看板页面;获取上级昵称
    @Test(description="获取上级昵称",priority = 13)
    public void 获取上级昵称() throws IOException{
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("sellerId",sellerId);
        Response response = network.getResponse(params,BOSS_BOSS);
        String data = response.jsonPath().getString("data");
        Assert.assertEquals(data,"喜洋洋保险",network.message(params,BOSS_BOSS,"昵称不匹配"));

    }


    //分享链接邀请下级加入
    @Test(description="邀请下级加入",priority = 14)
    public void 邀请下级加入() throws IOException{
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("inviteType",2);
        Response response = network.getResponse(params,BOSS_CODE);
        boolean invite = response.jsonPath().getBoolean("success");
        Assert.assertTrue(invite,network.message(params,BOSS_CODE,"分享链接失败"));

    }

    @AfterClass
    public static void tearDown(){
        apiCount += 9;
    }


}


