package com.kjj.qa.cases;

import com.google.inject.internal.asm.$TypePath;
import com.kjj.qa.utils.NetworkUtil;
import io.restassured.response.Response;

import org.apache.commons.lang3.ObjectUtils;
import org.codehaus.groovy.antlr.UnicodeEscapingReader;
import org.testng.Assert;
import org.testng.annotations.*;
import org.testng.annotations.Test;

import java.io.IOException;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static com.kjj.qa.config.BasicConfig.*;

public class CircleFriends {

    private static final NetworkUtil network = NetworkUtil.getInstance();
    int firstTagId = 0;
    String contentId = "";
    String tagId = "";
    String tagName = "";

    @BeforeClass
    public void setUp() {

    }

    @Test(description="是否首次进入",priority = 1)
    public void 是否首次进入() throws IOException {
        Map<String, Object> params = new HashMap<String, Object>();
        Response response = network.getResponse(FRIENDS_ISUSERFIRSTENTERANDCOLLECT);
        String desc = response.jsonPath().getString("desc");
        Assert.assertEquals(desc,"OK",network.message(FRIENDS_ISUSERFIRSTENTERANDCOLLECT,"是否首次进入和首次收藏发圈素材列表-接口有误"));
    }

    // tab列表  后端根据tku自行判断
    @Test(description="获取tab列表",priority = 2)
    public void 获取tab列表() throws IOException {
        Response response = network.getResponse(FRIENDS_GETMATERIALTAGS);

        int tabCount = response.jsonPath().getInt("data.size()");
        int id = response.jsonPath().getInt("data.find {it.name == '保险'}.id"); //标签tab
        firstTagId = response.jsonPath().getInt("data[0].id");//第一个标签的ID
        Assert.assertEquals(tabCount,6,network.message(FRIENDS_GETMATERIALTAGS,"获取tab数量有误"));
        Assert.assertEquals(id,595,network.message(FRIENDS_GETMATERIALTAGS,"获取tab中不包含保险"));
    }

    @Test(description="获取推荐(未读)列表",priority = 3)
    public void 获取推荐列表() throws IOException {
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("firstTagId",firstTagId);
        Response response = network.getResponse(params,FRIENDS_GETUNREADTIMELINSLIST);
        int count = response.jsonPath().getInt("data.size()");
        contentId = response.jsonPath().getString("data[0].contentId"); //素材ID
        tagId = response.jsonPath().getString("data[0].materialTag");   //素材频道ID
        tagName = response.jsonPath().getString("data[0].tagName");     //素材频道名称
        Assert.assertEquals(count,30,network.message(params,FRIENDS_GETUNREADTIMELINSLIST,"获取推荐列表有误"));
    }

    @Test(description="获取全部列表",priority = 4)
    public void 获取全部列表() throws IOException {
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("firstTagId",firstTagId);
        params.put("pageIndex",1);
        params.put("pageSize",10);
        Response response = network.getResponse(params,FRIENDS_GETTIMELINELIST);
        int count = response.jsonPath().getInt("data.list.size()");
        Assert.assertEquals(count,10,"获取未读列表有误");
    }

    @Test(description="素材标记为已读",priority = 5)
    public void 素材标记为已读() throws IOException, InterruptedException {
        //标记为已读
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("contentId",contentId);
        params.put("firstTagId",firstTagId);
        Response response = network.postResponse(params,FRIENDS_ASYNCMARKTIMELINEREAD);
        boolean data = response.jsonPath().getBoolean("data");
        Assert.assertTrue(data,network.message(params,FRIENDS_ASYNCMARKTIMELINEREAD,"标记已读-接口有误"));

        //延迟2秒，存入ES
        Thread.currentThread().sleep(2000);

        //重新获取未读列表
        response = network.getResponse(params,FRIENDS_GETUNREADTIMELINSLIST);
        List<String> contentList = response.jsonPath().getList("data.contentId");
        boolean unRead = contentList.contains(contentId); //检查是否未读，false为已读，true为未读
        Assert.assertFalse(unRead,network.message(params,FRIENDS_GETUNREADTIMELINSLIST,"已读后，未读接口没有过滤已读素材"));
    }

    @Test(description="收藏素材",priority = 6)
    public void 收藏素材() throws IOException {
        // 收藏素材
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("contentId",contentId);
        params.put("operate",1);
        Response response = network.getResponse(params,FRIENDS_ADDORCANCELCOLLECT);
        boolean isAdd = response.jsonPath().getBoolean("data");
        Assert.assertTrue(isAdd,network.message(params,FRIENDS_ADDORCANCELCOLLECT,"收藏素材失败"));

        // 查看收藏列表
        params.put("pageSize",12);
        response = network.getResponse(params,FRIENDS_QUERYLISTFORCOLLECT);
        String collectContentId = response.jsonPath().getString("data[0].contentId");
        Assert.assertEquals(collectContentId,contentId,network.message(params,FRIENDS_QUERYLISTFORCOLLECT,"收藏列表有误"));

        // 取消收藏
        params.put("operate",2);
        response = network.getResponse(params,FRIENDS_ADDORCANCELCOLLECT);
        boolean isCancel = response.jsonPath().getBoolean("data");
        Assert.assertTrue(isCancel,network.message(params,FRIENDS_ADDORCANCELCOLLECT,"取消收藏素材失败"));
    }

    @Test(description="素材频道页",priority = 7)
    public void 素材频道页() throws IOException {
        //频道页 头部
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("tagId",tagId);
        Response response = network.getResponse(params,FRIENDS_CHANNELDETAIL);
        String name = response.jsonPath().getString("data.tagName");
        Assert.assertEquals(name,tagName,network.message(params,FRIENDS_CHANNELDETAIL,"素材频道页-头部获取有误"));

        //频道页 列表
        params.put("pageSize",10);
        params.put("pageNo",1);
        response = network.getResponse(params,FRIENDS_GETCHANNELLIST);
        String collectTagtId = response.jsonPath().getString("data[0].materialTag"); //素材ID
        boolean hasList = response.jsonPath().getInt("data.size()") > 0;
        Assert.assertEquals(collectTagtId,tagId,network.message(params,FRIENDS_GETCHANNELLIST, "素材列表获取有误"));
        Assert.assertTrue(hasList,network.message(params,FRIENDS_GETCHANNELLIST,"素材频道列表-获取有误"));
    }

    @Test(description="从首页发圈列表页进入",priority = 8)
    public void 从首页发圈列表页进入() throws IOException {
        // 获取首页发圈素材列表
        Response response = network.getResponse(HOME_GETHOMETIMELINECONTENT);
        String currentId = response.jsonPath().getString("data.materialVos[0].contentId");
        Assert.assertNotNull(currentId,network.message(HOME_GETHOMETIMELINECONTENT,"获取首页发圈列表有误"));

        // 如果有推荐列表,进入发圈
        if (currentId.length() > 0){
            Map<String, Object> params = new HashMap<String, Object>();
            params.put("currentId",currentId);
            response = network.getResponse(params,FRIENDS_GETCURRENTINFO);
            String topContentId = response.jsonPath().getString("data.contentId");
            Assert.assertEquals(topContentId,currentId,network.message(params,FRIENDS_GETCURRENTINFO,"从首页进入发圈的头部素材有误"));
        }

    }

    @AfterClass
    public static void tearDown(){
        apiCount += 13;
    }

}
