package com.kjj.qa.cases;


import com.kjj.qa.utils.NetworkUtil;
import static com.kjj.qa.config.BasicConfig.*;
import io.restassured.response.Response;
import org.testng.Assert;
import org.testng.annotations.*;
import org.testng.annotations.Test;


import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

public class SellerCard {
    private static final NetworkUtil network = NetworkUtil.getInstance();

    private String scid = "";
    private String sellerId = "";

    @BeforeClass
    public void setUp() {

    }

    @Test(description = "获取用户版本", priority = 1) //priorty 方法执行优先级
    public void 获取用户版本() throws IOException {
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("t", System.currentTimeMillis());
        Response response = network.getResponse(params, VERSION_INFO);

        int userVersion = response.jsonPath().getInt("data.find {it.openType == 1}.userVersion"); // 找出开启状态的版本类型
        Assert.assertEquals(userVersion, 2, network.message(params, VERSION_INFO,"会员类型版本判断:判断错误,此版本为通用版"));
    }

    @Test(description = "是否关注红号", priority = 2) //priorty 方法执行优先级
    public void 是否关注红号() throws IOException {
        Response response = network.getResponse(ISVIPSUBSCRIBE);
        boolean vipSubscribe = response.jsonPath().getBoolean("data.vipSubscribe");
        Assert.assertFalse(false, network.message(ISVIPSUBSCRIBE,"vip号是否关注判断错误"));
    }


    @Test(description = "头部展示", priority = 3)
    public void 头部展示() throws IOException {
        //获取信息
        Response response = network.getResponse(SELLERCARD_TOPOFDETAIL);
        scid = response.jsonPath().getString("data.scid");
        sellerId = response.jsonPath().getString("data.sellerId");

        String sellerName = response.jsonPath().getString("data.sellerName");
        Assert.assertEquals(sellerName, WECHAT_NAME, network.message(SELLERCARD_TOPOFDETAIL,"获取用户失败"));

        //修改用户信息
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("sellerName", "测试123");
        params.put("phoneNumber", "13012341234");
        params.put("wechatNumber", "wx123456");
        params.put("address", "杭州数娱大厦(文一西路98号)");
        params.put("addressLocation", "120.112204,30.287785");
        params.put("avatarStyle", 3);
        Response editRsponse = network.postResponse(params, SELLERCARD_EDITBASEINFO);
        boolean isChanged = editRsponse.jsonPath().getBoolean("success");
        Assert.assertTrue(isChanged, network.message(params, SELLERCARD_EDITBASEINFO,"修改用户信息无效"));

        //重新获取用户信息
        response = network.getResponse(SELLERCARD_TOPOFDETAIL);
        sellerName = response.jsonPath().getString("data.sellerName");
        String phoneNumber = response.jsonPath().getString("data.phoneNumber");
        String wechatNumber = response.jsonPath().getString("data.wechatNumber");
        String address = response.jsonPath().getString("data.address");
        int avatarStyle = response.jsonPath().getInt("data.avatarStyle");
        Assert.assertEquals(sellerName, "测试123", network.message(SELLERCARD_TOPOFDETAIL,"修改后的姓名不正确"));
        Assert.assertEquals(phoneNumber, "13012341234", network.message(SELLERCARD_TOPOFDETAIL,"修改后的手机号不正确"));
        Assert.assertEquals(wechatNumber, "wx123456", network.message(SELLERCARD_TOPOFDETAIL,"修改后的微信号不正确"));
        Assert.assertEquals(address, "杭州数娱大厦(文一西路98号)", network.message(SELLERCARD_TOPOFDETAIL,"修改后的地址不正确"));
    }

    @Test(description = "专业介绍", priority = 4)
    public void 专业介绍() throws IOException {
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("scid", scid);
        Response response = network.getResponse(params, SELLERCARD_PERSONALPROFILE);
        String intro = response.jsonPath().getString("data.personalIntro"); //个人介绍
        int exprLength = response.jsonPath().getInt("data.exprLength"); //工作年限
//        Assert.assertEquals(intro,"我在行业内深耕多年，经验丰富，具备过硬的专业素质，深受客户喜爱和支持。","个人介绍-获取介绍不匹配");
        Assert.assertEquals(exprLength, 0, network.message(params, SELLERCARD_PERSONALPROFILE,"个人介绍-获取工作年限不匹配"));


        //修改工作年限和个人介绍
        Map<String, Object> baseParams = new HashMap<String, Object>();
        baseParams.put("exprLength", 2);
        baseParams.put("personalIntro", "我在行业内整挺好!");
        Response baseResponse = network.postResponse(baseParams, SELLERCARD_EDITBASEINFO);
        boolean isChanged = baseResponse.jsonPath().getBoolean("success");
        Assert.assertTrue(isChanged, network.message(baseParams, SELLERCARD_EDITBASEINFO,"修改工作年限和个人介绍无效"));

        //修改擅长专业
        Map<String, Object> personalParams = new HashMap<String, Object>();
        personalParams.put("goodAtCustom", "嘻嘻哈哈");
        personalParams.put("goodAtDefault", "16");
        Response personalResponse = network.postResponse(personalParams, SELLERCARD_EDITMAJORGOODAUTH);
        isChanged = personalResponse.jsonPath().getBoolean("success");
        Assert.assertTrue(isChanged, network.message(personalParams, SELLERCARD_EDITBASEINFO,"修改擅长专业无效"));

        //查看修改后的专业介绍
        response = network.getResponse(params, SELLERCARD_PERSONALPROFILE);
        intro = response.jsonPath().getString("data.personalIntro"); //个人介绍
        exprLength = response.jsonPath().getInt("data.exprLength"); //工作年限
        boolean isChooseGoodAtDefault = response.jsonPath().getBoolean("data.goodAtMajor.find {it.code == '16'}.choose");
        Assert.assertEquals(intro, "我在行业内整挺好!", network.message(params, SELLERCARD_PERSONALPROFILE,"修改个人介绍失败"));
        Assert.assertEquals(exprLength, 2, network.message(params, SELLERCARD_PERSONALPROFILE,"修改工作年限失败"));
        Assert.assertTrue(isChooseGoodAtDefault, network.message(params, SELLERCARD_PERSONALPROFILE,"选择默认擅长专业失效"));
    }

    @Test(description = "客户评价", priority = 5) //priorty 方法执行优先级
    public void 客户评价() throws IOException {
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("scid", scid);
        params.put("pageIndex", 1);
        params.put("pageSize", 3);
        params.put("appraiseState", 1);
        params.put("isPersonal", false);

        Response response = network.getResponse(params, SELLERCARD_APPRAISELISTNEW);
        boolean hasAppraise = response.jsonPath().getInt("data.appraiseList.totalCount") > 0;
        Assert.assertTrue(hasAppraise, network.message(params, SELLERCARD_APPRAISELISTNEW,"获取用户评价失败"));

        params.put("isPersonal", true);
        response = network.getResponse(params, SELLERCARD_APPRAISELISTNEW);
        hasAppraise = response.jsonPath().getInt("data.appraiseList.totalCount") == 0;
        Assert.assertTrue(hasAppraise, network.message(params, SELLERCARD_APPRAISELISTNEW,"获取专业评价失败"));
    }

    @Test(description = "互动问答", priority = 6) //priorty 方法执行优先级
    public void 互动问答() throws IOException {
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("scid", scid);
        Response response = network.getResponse(params, SELLERCARD_GETQUESTIONS);
        int qurstionsCount = response.jsonPath().getInt("data.questionList.size()");
        Assert.assertEquals(qurstionsCount, 2, network.message(params, SELLERCARD_GETQUESTIONS,"获取用户评价失败"));
    }

    @Test(description = "风险评测", priority = 7) //priorty 方法执行优先级
    public void 风险评测() throws IOException {
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("scid", scid);
        Response response = network.getResponse(params, SELLERCARD_ISDISPLAYACTIVITY);
        String contentId = response.jsonPath().getString("data.contentId");//写死风险评测id
        Assert.assertEquals(contentId, "Kj21MzY5OTk", network.message(params, SELLERCARD_ISDISPLAYACTIVITY,"风险评测-获取失败"));
    }

    //
    @Test(description = "选择公司", priority = 8) //priorty 方法执行优先级
    public void 选择公司() throws IOException {
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("pageIndex", 1);
        params.put("pageSize", 200);
        Response response = network.getResponse(params, SELLERCARD_COMPANYLIST);
        String companyId = response.jsonPath().getString("data.list.find {it.companyName == '杭州兑吧网络科技有限公司'}.id");
        Assert.assertNotNull(companyId, network.message(params, SELLERCARD_COMPANYLIST,"公司列表-获取失败"));


        Map<String, Object> editParams = new HashMap<String, Object>();
        editParams.put("companyId", companyId);
        response = network.postResponse(editParams, SELLERCARD_EDITBASEINFO);
        boolean isChanged = response.jsonPath().getBoolean("success");
        Assert.assertTrue(isChanged, network.message(editParams, SELLERCARD_EDITBASEINFO,"选择公司失效"));
    }

    @Test(description = "服务案例", priority = 9) //priorty 方法执行优先级
    public void 服务案例() throws IOException {
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("scid",scid);
        params.put("pageSize",4);
        Response response = network.getResponse(params, SELLERCARD_SELLERCARDCASENEW);
        int count = response.jsonPath().getInt("data.cases.size()");
        Assert.assertEquals(count,3, network.message(params, SELLERCARD_SELLERCARDCASENEW,"服务案例-获取失败"));
    }

    @Test(description = "精选产品", priority = 10) //priorty 方法执行优先级
    public void 精选产品() throws IOException {
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("scid",scid);
        params.put("pageSize",3);
        params.put("isMore",false);
        Response response = network.getResponse(params, SELLERCARD_PRODUCTLIST);
        int count = response.jsonPath().getInt("data.productList.size()");
        Assert.assertEquals(count,3,network.message(params, SELLERCARD_PRODUCTLIST,"精选产品-获取失败"));
    }

    @AfterClass
    public static void tearDown(){
        apiCount += 12;
    }
}
