package com.kjj.qa.cases;

import static com.kjj.qa.config.BasicConfig.*;
import com.kjj.qa.utils.NetworkUtil;
import io.restassured.response.Response;
import org.testng.Assert;
import org.testng.annotations.*;
import org.testng.annotations.Test;


import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

public class Upload {
    private static final NetworkUtil network = NetworkUtil.getInstance();

    @BeforeClass
    public void setUp() {

    }

    @Test(description="会员判断",priority = 1)
    public void 会员判断() throws IOException{
        Response response = network.getResponse(ISVIPSUBSCRIBE);
        boolean isVip = response.jsonPath().getBoolean("data.vip");
        Assert.assertTrue(true, network.message(ISVIPSUBSCRIBE,"会员判断错误"));
    }

    @Test(description = "上传_文章链接",priority = 2)
    public void 上传_文章链接() throws IOException {
        //待上传的文章链接
        String articleLink = "https://mp.weixin.qq.com/s/j4qnDM98d2ZPW35ozFra8w";

        //开始上传
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("url",articleLink);
        params.put("type",1);
        Response response = network.postResponse(params,UPLOAD);
        String taskId = response.jsonPath().getString("data.taskId");
        Assert.assertNotNull(taskId ,network.message(params,UPLOAD,"上传文章链接-接口调用失败"));

        //查询上传状态  轮询30次，直至taskStatus变为2
        Map<String, Object> taskParams = new HashMap<String, Object>();
        taskParams.put("taskId",taskId);
        response = network.getResponse(taskParams,UPLOAD_TASKSTATUS);
        int taskStatus = response.jsonPath().getInt("data.taskStatus");//上传状态: 1是执行中，2是上传成功
        String contentId = response.jsonPath().getString("data.contentId");//内容ID
        String contentImageUrl = response.jsonPath().getString("data.contentImageUrl");
        String contentType = response.jsonPath().getString("data.contentType");
        Assert.assertEquals(contentType,"article", network.message(taskParams, UPLOAD_TASKSTATUS,"上传文章链接-查询调用失败"));
    }

    @Test(description="上传_视频链接",priority = 3)
    public void 上传_视频链接() throws IOException{
        //待上传的视频链接
        String videoLink = "https://v.douyin.com/oEahcd/ 复制此链接，打开【抖音短视频】，直接观看视频！";

        //开始上传
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("url",videoLink);
        params.put("type",3);
        Response response = network.postResponse(params,UPLOAD);
        String taskId = response.jsonPath().getString("data.taskId");
        Assert.assertNotNull(taskId ,network.message(params, UPLOAD,"上传视频链接-接口调用失败"));

        //查询上传状态  轮询30次，直至taskStatus变为2
        Map<String, Object> taskParams = new HashMap<String, Object>();
        taskParams.put("taskId",taskId);
        response = network.getResponse(taskParams,UPLOAD_TASKSTATUS);
        int taskStatus = response.jsonPath().getInt("data.taskStatus");//上传状态: 1是执行中，2是上传成功
        String contentId = response.jsonPath().getString("data.contentId");//内容ID
        String contentImageUrl = response.jsonPath().getString("data.contentImageUrl");
        String responseTaskId = response.jsonPath().getString("data.taskId");
        Assert.assertEquals(responseTaskId,taskId,network.message(taskParams, UPLOAD_TASKSTATUS,"上传视频链接-查询调用失败"));
}

    @Test(description = "上传_其他链接",priority = 4)
    public void 上传_其他链接() throws IOException {
        //待上传的其他链接
        String network_link = "https://tieba.baidu.com/p/6688007444";

        //开始上传
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("type",2);
        params.put("url",network_link);
        Response response = network.postResponse(params, UPLOAD);
        String taskId = response.jsonPath().getString("data.taskId");//上传任务ID
        Assert.assertNotNull(taskId,network.message(params, UPLOAD,"上传其他链接-接口调用失败"));

        //查询上传状态  轮询30次，直至taskStatus变为2
        Map<String, Object> taskParams = new HashMap<String, Object>();
        taskParams.put("taskId",taskId);
        response = network.getResponse(taskParams,UPLOAD_TASKSTATUS);
        int taskStatus = response.jsonPath().getInt("data.taskStatus");//上传状态: 1是执行中，2是上传成功
        String contentId = response.jsonPath().getString("data.contentId");//内容ID
        String contentImageUrl = response.jsonPath().getString("data.contentImageUrl");
        String contentType = response.jsonPath().getString("data.contentType");
        Assert.assertEquals(contentType,"network_link",network.message(taskParams, UPLOAD_TASKSTATUS,"上传其他链接-查询调用失败"));

        //获取 其他链接上传成功后的中间页详情
        Map<String, Object> detailParams = new HashMap<String, Object>();
        detailParams.put("contentId",contentId);
        response = network.getResponse(detailParams, UPLOAD_CONTENTDETAIL);
        String sourceUrl = response.jsonPath().get("data.sourceUrl");
        Assert.assertEquals(sourceUrl, network_link,network.message(detailParams, UPLOAD_CONTENTDETAIL,"上传其他链接-中间页获取失败"));

        //上传和分享
        Map<String, Object> updateParams = new HashMap<String, Object>();
        updateParams.put("contentId",contentId);
        updateParams.put("contentImageUrl",contentImageUrl);
        response = network.postResponse(updateParams, UPLOAD_UPDATEANDSHARE);
        String shareLink = response.jsonPath().getString("data.shareLink");
        Assert.assertEquals(shareLink, network_link,network.message(updateParams, UPLOAD_UPDATEANDSHARE,"传其他链接-上传和分享调用失败"));
    }

    @Test(description = "上传_本地视频",priority = 5)
    public void 上传_本地视频() throws IOException {
        //1.上传视频到oss
        String videoFile = "src/test/java/com/kjj/qa/resource/uploadCase.mp4";
        Response response = network.postFileResponse(videoFile, UPLOAD_UPLOADVEDIO);
        String videoUrl = response.jsonPath().getString("data.videoUrl");
        String firstFrameUrl = response.jsonPath().getString("data.firstFrameUrl");
        Assert.assertNotNull(videoUrl, network.message(UPLOAD_UPLOADVEDIO,"上传本地视频-上传oss失败"));

        //2.开始上传视频
//        Map<String, Object> params = new HashMap<String, Object>();
//        params.put("videoUrl",videoUrl);
//        params.put("firstFrameUrl",firstFrameUrl);
//        params.put("contentTitle","=自动化测试=");
//        response = network.postResponse(params, UPLOAD_SELLERUPLOADVEDIO);
//        String contentId = response.jsonPath().getString("data.contentId");
//        Assert.assertNotNull(contentId,network.message(params, UPLOAD_SELLERUPLOADVEDIO,"上传本地视频-上传第2步失败"));
    }

    @Test(description="大家都在转_榜单列表",priority = 6)
    public void 大家都在转_榜单列表() throws IOException{
        //获取文章的榜单
        Response response = network.getResponse(UPLOAD_HOT);
        String contentType = response.jsonPath().getString("data[0].contentType");//列表的素材类型
        boolean isList = response.jsonPath().getInt("data.size()") > 0;//列表的长度
        Assert.assertEquals(contentType, "article", network.message(UPLOAD_HOT,"获取大家都在转-文章列表内容有误"));
        Assert.assertTrue( isList, network.message(UPLOAD_HOT,"获取大家都在转-文章列表数量有误"));

        //获取视频的榜单
        response = network.getResponse(UPLOAD_VIDEOHOT);
        contentType = response.jsonPath().getString("data[0].contentType");
        isList = response.jsonPath().getInt("data.size()") > 0;
        Assert.assertEquals(contentType, "video", network.message(UPLOAD_VIDEOHOT,"获取大家都在转-视频列表内容有误"));
        Assert.assertTrue(isList, network.message(UPLOAD_VIDEOHOT,"获取大家都在转-视频列表数量有误"));
    }

    //我的上传：
    @Test(description="我的上传",priority = 7)
    public void 我的上传() throws IOException{
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("pageIndex",1);
        params.put("pageNo",1);
        params.put("pageSize",10);

        //获取文章的列表
        params.put("type","article");
        Response response = network.getResponse(params,UPLOAD_LIST);
        int length = response.jsonPath().getInt("data.size()");
        String contentType = response.jsonPath().getString("data[0].contentType");
        Assert.assertEquals(length, 1, network.message(params, UPLOAD_LIST,"获取我的上传-文章列表内容有误"));
        Assert.assertEquals(contentType, "article", network.message(params, UPLOAD_LIST,"获取我的上传-文章列表数量有误"));

        //获取视频的列表
        params.put("type","video");
        response = network.getResponse(params, UPLOAD_LIST);
        length = response.jsonPath().getInt("data.size()");
        contentType = response.jsonPath().getString("data[0].contentType");
        Assert.assertEquals(length, 1, network.message(params, UPLOAD_LIST,"获取我的上传-视频列表内容有误"));//因为有一篇抖音，一篇本地，所以数量是2
        Assert.assertEquals(contentType, "video", network.message(params, UPLOAD_LIST,"获取我的上传-视频列表数量有误"));

        //获取其他的列表
        params.put("type","network_link");
        response = network.getResponse(params, UPLOAD_LIST);
        String network_linkId = response.jsonPath().getString("data[0].id");//获取列表的第一篇素材

        length = response.jsonPath().getInt("data.size()");
        contentType = response.jsonPath().getString("data[0].contentType");
        Assert.assertEquals(length, 1, network.message(params, UPLOAD_LIST,"获取我的上传-其他列表失败"));
        Assert.assertEquals(contentType, "network_link", network.message(params, UPLOAD_LIST,"获取我的上传-其他列表数量有误"));

        //删除其他列表的素材
        Map<String, Object> unbindParams = new HashMap<String, Object>();
        unbindParams.put("id",network_linkId);
        response = network.getResponse(unbindParams,UPLOAD_UNBIND);
        boolean data = response.jsonPath().getBoolean("data");
        Assert.assertTrue(data,network.message(unbindParams, UPLOAD_UNBIND,"删除我的上传-其他列表的素材失败"));

        //再次获取其他的列表, 检查删除是否生效
        response = network.getResponse(params, UPLOAD_LIST);
        length = response.jsonPath().getInt("data.size()");
        Assert.assertEquals(length, 0, network.message(params, UPLOAD_LIST,"获取我的上传-其他列表数量有误"));
    }

    @AfterClass
    public static void tearDown(){
        apiCount += 13;
    }

}