package com.kjj.qa.utils;
import static com.kjj.qa.config.BasicConfig.*;
import static io.restassured.RestAssured.*;

import com.alibaba.fastjson.JSONObject;
import io.restassured.http.Cookies;
import io.restassured.response.Response;

import java.io.File;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;


public class NetworkUtil {

    // 代理人的 cookies和headers
    public Map<String, Object> agentCookies = new HashMap<String, Object>();
    public Map<String, Object> getAgentCookies() { return agentCookies; }
    public void setAgentCookies(Map<String, Object> agentCookies) { this.agentCookies = agentCookies; }

    public Map<String, Object> agentHeaders = new HashMap<String, Object>();
    public Map<String, Object> getAgentHeaders() { return agentHeaders; }
    public void setAgentHeaders(Map<String, Object> agentHeaders) { this.agentHeaders = agentHeaders; }

    public Map<String, Object> fileHeaders = new HashMap<String, Object>();
    public Map<String, Object> getFileHeaders() { return fileHeaders; }
    public void setFileHeadersHeaders(Map<String, Object> fileHeaders) { this.fileHeaders = fileHeaders; }

    public String host = "";
    public String getHost() {return  host;}
    public void setHost(String host) {this.host = host;}

    // 钉钉的 headers
    public Map<String, Object> dingTalkHeaders = new HashMap<String, Object>();
    public Map<String, Object> getDingTalkHeaders() { return dingTalkHeaders; }
    public void setDingTalkHeaders(Map<String, Object> dingTalkHeaders) { this.dingTalkHeaders = dingTalkHeaders; }

    private volatile static NetworkUtil network;

    // 构造函数 初始化tku、content-type
    private NetworkUtil (){
        //配置地址
        host = HOST;
        //cookies中的tku
        agentCookies.put("tku",AGENT_TKU);
        //json类型的headers
        agentHeaders.put("Content-Type","application/json");
        //二进制文件的headers
        fileHeaders.put("Content-Type","multipart/form-data");
        //钉钉的headers
        dingTalkHeaders.put("Content-Type","application/json;charset=utf-8");
    }

    //单例模式
    //通过设置同步代码块，使用DCL双检查锁机制
    //使用双检查锁机制成功的解决了单例模式的懒汉实现的线程不安全问题和效率问题
    //DCL 也是大多数多线程结合单例模式使用的解决方案
    public static NetworkUtil getInstance() {
        if (network == null) {
            synchronized (NetworkUtil.class) {
                if (network == null) {
                    network = new NetworkUtil();
                }
            }
        }
        return network;
    }


    // get 不带参请求
    public Response getResponse(String path) {
        return given()
                .cookies(agentCookies)
                .headers(agentHeaders)
                .get(host + path);
    }

    // get 带参请求
    public Response getResponse(Map<String, Object> params, String path) {
        return given()
                .cookies(agentCookies)
                .headers(agentHeaders)
                .params(params)
                .get(host + path);
    }

    // post 不帶参请求
    public Response postResponse(String path) {
        return given()
                .cookies(agentCookies)
                .headers(agentHeaders)
                .post(host + path);
    }

    // post 带参请求
    public Response postResponse(Map<String, Object> params, String path) {
        String jsonStr = JSONObject.toJSONString(params);
        return given()
                .cookies(agentCookies)
                .headers(agentHeaders)
                .body(jsonStr)
                .post(host + path);
    }

    // post 文件上传
    public Response postFileResponse(String filePath, String path){
        return given()
                .cookies(agentCookies)
                .headers(fileHeaders)
                .multiPart("file",new File(filePath))
                .post(host + path);
    }

    // post 钉钉机器人
    public Response dingTalkRobot(Map<String, Object> params) {
        String jsonStr = JSONObject.toJSONString(params);
        return given()
                .headers(dingTalkHeaders)
                .body(jsonStr)
                .post(DINGTALKPATH);
    }

    //带参的接口信息
    public String message(Map<String, Object> params, String path, String errorMessage){
        return  "\n" + "path: " + path +
                "\n" + "params: " + params +
                "\n" + "message: " + errorMessage;
    }

    //不带参的接口信息
    public String message(String path, String errorMessage){
        return  "\n" + "path: " + path +
                "\n" + "message: " + errorMessage;
    }


    public static void main(String[] args) throws IOException {

    }


}
